@@ -165,6 +165,7 @@ Options:
                         vulkan1.1
                         vulkan1.2
                         vulkan1.3
+                        vulkan1.4
                         vulkan          # Same as vulkan1.0
                         opengl4.5
                         opengl          # Same as opengl4.5
@@ -174,8 +175,9 @@ Options:
                     required to be supported for the target environment.
                     For example, default for vulkan1.0 is spv1.0, and
                     the default for vulkan1.1 is spv1.3,
-                    the default for vulkan1.2 is spv1.5.
-                    the default for vulkan1.3 is spv1.6.
+                    the default for vulkan1.2 is spv1.5,
+                    the default for vulkan1.3 is spv1.6,
+                    the default for vulkan1.4 is spv1.6.
                     Values are:
                         spv1.0, spv1.1, spv1.2, spv1.3, spv1.4, spv1.5, spv1.6
   --version         Display compiler version information.
@@ -265,8 +267,9 @@ int main(int argc, char** argv) {
 
   // Sets binding base for the given uniform kind.  If stage is
   // shader_glsl_infer_from_source then set it for all shader stages.
-  auto set_binding_base = [&compiler](
-      shaderc_shader_kind stage, shaderc_uniform_kind kind, uint32_t base) {
+  auto set_binding_base = [&compiler](shaderc_shader_kind stage,
+                                      shaderc_uniform_kind kind,
+                                      uint32_t base) {
     if (stage == shaderc_glsl_infer_from_source)
       compiler.options().SetBindingBase(kind, base);
     else
@@ -452,6 +455,9 @@ int main(int argc, char** argv) {
       } else if (target_env_str == "vulkan1.3") {
         target_env = shaderc_target_env_vulkan;
         version = shaderc_env_version_vulkan_1_3;
+      } else if (target_env_str == "vulkan1.4") {
+        target_env = shaderc_target_env_vulkan;
+        version = shaderc_env_version_vulkan_1_4;
       } else if (target_env_str == "opengl") {
         target_env = shaderc_target_env_opengl;
       } else if (target_env_str == "opengl4.5") {
@@ -675,9 +681,10 @@ int main(int argc, char** argv) {
       // from the file name. If current_fshader_stage is specifed to one of
       // the forced shader kinds, use that for the following compilation.
       input_files.emplace_back(glslc::InputFileSpec{
-          arg.str(), (current_fshader_stage == shaderc_glsl_infer_from_source
-                          ? glslc::DeduceDefaultShaderKindFromFileName(arg)
-                          : current_fshader_stage),
+          arg.str(),
+          (current_fshader_stage == shaderc_glsl_infer_from_source
+               ? glslc::DeduceDefaultShaderKindFromFileName(arg)
+               : current_fshader_stage),
           language, current_entry_point_name});
     }
   }
